
//////////////////////////////////////////////////////////////////////////
//
// Conventions:
//
// +x = left
// +z = rear
// +y = up
// +pitch = nose up
// +yaw = nose right
// +roll = right
//
// [BODY]  - a rigid mass with mass and inertial properties
// [JOINT] - a ball joint constraining an offset of one body to an
//           offset of another body (eliminates 3 DOF)
// [HINGE] - a constraint restricting the relative rotations of two
//           bodies to be around a single axis (eliminates 2 DOF).
// [BAR]   - a constraint holding an offset of one body from an offset of
//           another body at a fixed distance (eliminates 1 DOF).
// [JOINT&HINGE] - both the joint and hinge constraints, forming the
//           conventional definition of a hinge (eliminates 5 DOF).
//
//////////////////////////////////////////////////////////////////////////

// Body including all rigidly attached parts (wings, barge boards, etc.)
[BODY]
name=body mass=(884.0) inertia=(2750.0,2846.3,446.2)
pos=(0.0,0.0,0.0) ori=(0.0,0.0,0.0)

// Front spindles
[BODY]
name=fl_spindle mass=(12.0) inertia=(0.0175,0.0160,0.0145)
pos=(0.68,0.0,-1.90) ori=(0.0,0.0,0.0)

[BODY]
name=fr_spindle mass=(12.0) inertia=(0.0175,0.0160,0.0145)
pos=(-0.68,0.0,-1.90) ori=(0.0,0.0,0.0)

// Front wheels
[BODY]
name=fl_wheel mass=(15.0) inertia=(0.792,0.524,0.524)
pos=(0.73,0.0,-1.90) ori=(0.0,0.0,0.0)

[BODY]
name=fr_wheel mass=(15.0) inertia=(0.792,0.524,0.524)
pos=(-0.73,0.0,-1.90) ori=(0.0,0.0,0.0)

// Rear spindles
[BODY]
name=rl_spindle mass=(12.5) inertia=(0.0175,0.0160,0.0145)
pos=(0.65,0.0,1.65) ori=(0.0,0.0,0.0)

[BODY]
name=rr_spindle mass=(12.5) inertia=(0.0175,0.0160,0.0145)
pos=(-0.65,0.0,1.65) ori=(0.0,0.0,0.0)

// Rear wheels (includes half of rear-axle)
[BODY]
name=rl_wheel mass=(21.0) inertia=(0.846,0.575,0.575)
pos=(0.70,0.0,1.65) ori=(0.0,0.0,0.0)

[BODY]
name=rr_wheel mass=(21.0) inertia=(0.846,0.575,0.575)
pos=(-0.70,0.0,1.65) ori=(0.0,0.0,0.0)


//////////////////////////////////////////////////////////////////////////
//
// Constraints
//
//////////////////////////////////////////////////////////////////////////

// Front wheel and spindle connections
[JOINT&HINGE]
posbody=fl_wheel negbody=fl_spindle pos=fl_wheel axis=(-1.0,0.0,0.0)

[JOINT&HINGE]
posbody=fr_wheel negbody=fr_spindle pos=fr_wheel axis=(1.0,0.0,0.0)

// Front left suspension (2 A-arms + 1 steering arm = 5 links)
[BAR] // forward upper arm
name=fl_fore_upper posbody=body negbody=fl_spindle pos=(0.15,0.1,-1.9) neg=(0.55,0.1,-1.9)

[BAR] // rearward upper arm
posbody=body negbody=fl_spindle pos=(0.15,0.1,-1.70) neg=(0.55,0.1,-1.9)

[BAR] // forward lower arm
posbody=body negbody=fl_spindle pos=(0.07,-0.1,-1.9) neg=(0.55,-0.1,-1.9)

[BAR] // rearward lower arm
name=fl_fore_lower posbody=body negbody=fl_spindle pos=(0.07,-0.1,-1.70) neg=(0.55,-0.1,-1.9)

[BAR] // steering arm (must be named for identification)
name=fl_steering posbody=body negbody=fl_spindle pos=(0.15,0.1,-2.0) neg=(0.55,0.1,-2.0)

// Front right suspension (2 A-arms + 1 steering arm = 5 links)
[BAR] // forward upper arm (used in steering lock calculation)
name=fr_fore_upper posbody=body negbody=fr_spindle pos=(-0.15,0.1,-1.9) neg=(-0.55,0.1,-1.9)

[BAR] // rearward upper arm
posbody=body negbody=fr_spindle pos=(-0.15,0.1,-1.70) neg=(-0.55,0.1,-1.9)

[BAR] // forward lower arm
name=fr_fore_lower posbody=body negbody=fr_spindle pos=(-0.07,-0.1,-1.9) neg=(-0.55,-0.1,-1.9)

[BAR] // rearward lower arm
posbody=body negbody=fr_spindle pos=(-0.07,-0.1,-1.70) neg=(-0.55,-0.1,-1.9)

[BAR] // steering arm (must be named for identification)
name=fr_steering posbody=body negbody=fr_spindle pos=(-0.15,0.1,-2.0) neg=(-0.55,0.1,-2.0)

// Rear left suspension (2 A-arms + 1 straight link = 5 links)
[BAR] // forward upper arm
posbody=body negbody=rl_spindle pos=(0.11,0.1,1.35) neg=(0.52,0.1,1.65)

[BAR] // rearward upper arm
posbody=body negbody=rl_spindle pos=(0.11,0.1,1.70) neg=(0.52,0.1,1.65)

[BAR] // forward lower arm
posbody=body negbody=rl_spindle pos=(0.08,-0.1,1.35) neg=(0.52,-0.1,1.65)

[BAR] // rearward lower arm
posbody=body negbody=rl_spindle pos=(0.08,-0.1,1.70) neg=(0.52,-0.1,1.65)

[BAR] // straight link
posbody=body negbody=rl_spindle pos=(0.075,-0.05,1.7) neg=(0.52,-0.05,1.7)

// Rear right suspension (2 A-arms + 1 straight link = 5 links)
[BAR] // forward upper arm
posbody=body negbody=rr_spindle pos=(-0.11,0.1,1.35) neg=(-0.52,0.1,1.65)

[BAR] // rearward upper arm
posbody=body negbody=rr_spindle pos=(-0.11,0.1,1.70) neg=(-0.52,0.1,1.65)

[BAR] // forward lower arm
posbody=body negbody=rr_spindle pos=(-0.08,-0.1,1.35) neg=(-0.52,-0.1,1.65)

[BAR] // rearward lower arm
posbody=body negbody=rr_spindle pos=(-0.08,-0.1,1.70) neg=(-0.52,-0.1,1.65)

[BAR] // straight link
posbody=body negbody=rr_spindle pos=(-0.075,-0.05,1.7) neg=(-0.52,-0.05,1.7)

// Rear spindle and wheel connections
[JOINT&HINGE]
posbody=rl_wheel negbody=rl_spindle pos=rl_wheel axis=(-1.0,0.0,0.0)

[JOINT&HINGE]
posbody=rr_wheel negbody=rr_spindle pos=rr_wheel axis=(1.0,0.0,0.0)



